Module: Gourami::Plugins::Sanitize
- Defined in:
- lib/gourami/plugins/sanitize.rb
Defined Under Namespace
Modules: InstanceMethods
Class Method Summary collapse
-
.apply(_model) ⇒ Object
Runs on every
plugin :sanitizecall; require is idempotent so this is safe to repeat.
Class Method Details
.apply(_model) ⇒ Object
Runs on every plugin :sanitize call; require is idempotent so this is safe to repeat.
15 16 17 |
# File 'lib/gourami/plugins/sanitize.rb', line 15 def self.apply(_model, *) require "loofah" end |